@@ -372,6 +372,24 @@ sub detect_quiet {
   return $quiet;
 }
 
+sub compile_single {
+  my ($self, $compile_info, $config) = @_;
+
+  # Quiet output
+  my $quiet = $self->detect_quiet($config);
+  
+  my $source_file = $compile_info->{source_file};
+
+  # Execute compile command
+  my $cbuilder = ExtUtils::CBuilder->new(quiet => 1);
+  my $cc_cmd = $self->create_compile_command($compile_info);
+  $cbuilder->do_system(@$cc_cmd)
+    or confess "Can't compile $source_file: @$cc_cmd";
+  unless ($quiet) {
+    warn "@$cc_cmd\n";
+  }
+}
+
 sub compile {
   my ($self, $class_name, $options) = @_;
   
@@ -401,9 +419,6 @@ sub compile {
   # Config
   my $config = $options->{config};
   
-  # Quiet output
-  my $quiet = $self->detect_quiet($config);
-
   # Force compile
   my $force = $self->detect_force($config);
 
@@ -519,14 +534,7 @@ sub compile {
       my $work_output_dir = "$output_dir/$class_rel_dir";
       mkpath dirname $object_file;
       
-      # Execute compile command
-      my $cbuilder = ExtUtils::CBuilder->new(quiet => $quiet);
-      my $cc_cmd = $self->create_compile_command($compile_info);
-      $cbuilder->do_system(@$cc_cmd)
-        or confess "Can't compile $source_file: @$cc_cmd";
-      unless ($quiet) {
-        warn "@$cc_cmd\n";
-      }
+      $self->compile_single($compile_info, $config);
     }
     
     # Object file information
@@ -714,6 +722,17 @@ sub create_dl_func_list {
   return $dl_func_list;
 }
 
+# This is used only for linker output for debug
+sub create_link_command {
+  my ($self, $ld, $output_file, $object_files, $cbuilder_extra_linker_flags) = @_;
+  
+  my @link_command = ($ld, '-o', $output_file, @$object_files, $cbuilder_extra_linker_flags);
+  
+  my $link_command = join(' ', @link_command);
+  
+  return $link_command;
+}
+
 sub link {
   my ($self, $class_name, $object_file_infos, $options) = @_;
   
@@ -734,9 +753,6 @@ sub link {
     confess "Need config option";
   }
 
-  # Quiet output
-  my $quiet = $self->detect_quiet($config);
-
   # Force link
   my $force = $self->detect_force($config);
   
@@ -783,6 +799,9 @@ sub link {
       perllibs => '-lm',
     };
 
+    # Quiet output
+    my $quiet = $self->detect_quiet($config);
+
     # ExtUtils::CBuilder object
     my $cbuilder = ExtUtils::CBuilder->new(quiet => $quiet, config => $cbuilder_config);
     
@@ -818,6 +837,10 @@ sub link {
         extra_linker_flags => $cbuilder_extra_linker_flags,
         dl_func_list => $dl_func_list,
       );
+      unless ($quiet) {
+        my $link_command = $self->create_link_command($ld, $link_info_output_file, $link_info_object_files, $cbuilder_extra_linker_flags);
+        warn "$link_command\n";
+      }
     }
     # Create a static library
     elsif ($output_type eq 'static_lib') {
@@ -825,6 +848,9 @@ sub link {
       my @ar_cmd = ('ar', 'rc', $link_info_output_file, @object_files);
       $cbuilder->do_system(@ar_cmd)
         or confess "Can't execute command @ar_cmd";
+      unless ($quiet) {
+        warn "@ar_cmd\n";
+      }
     }
     # Create an executable file
     elsif ($output_type eq 'exe') {
@@ -834,6 +860,10 @@ sub link {
         exe_file => $link_info_output_file,
         extra_linker_flags => $cbuilder_extra_linker_flags,
       );
+      unless ($quiet) {
+        my $link_command = $self->create_link_command($ld, $link_info_output_file, $link_info_object_files, $cbuilder_extra_linker_flags);
+        warn "$link_command\n";
+      }
     }
     else {
       confess "Unknown output_type \"$output_type\"";
