@@ -4,11 +4,11 @@ package SPVM::Fn;
 
 =encoding utf8
 
-=head1 NAME
+=head1 Name
 
 SPVM::Fn - SPVM Starndard Functions
 
-=head1 SYNOPSYS
+=head1 Synopsys
 
   use Fn;
   
@@ -136,71 +136,11 @@ SPVM::Fn - SPVM Starndard Functions
     return $new_int_obj;
   });
 
-  # Sort byte array itself by asc order
-  my $nums = [(byte)2, 3, 1];
-  Fn->sort_byte($nums, 0, scalar @$nums, method : int ($a : byte, $b : byte) {
-    return $a <=> $b;
-  });
-
-  # Sort short array itself by asc order
-  my $nums = [(short)2, 3, 1];
-  Fn->sort_short($nums, 0, scalar @$nums, method : int ($a : short, $b : short) {
-    return $a <=> $b;
-  });
-
-  # Sort int array itself by asc order
-  my $nums = [2, 3, 1];
-  Fn->sort_int($nums, 0, scalar @$nums, method : int ($a : int, $b : int) {
-    return $a <=> $b;
-  });
-
-  # Sort long array itself by asc order
-  my $nums = [(long)2, 3, 1];
-  Fn->sort_long($nums, 0, scalar @$nums, method : int ($a : long, $b : long) {
-    return $a <=> $b;
-  });
-
-  # Sort float array itself by asc order
-  my $nums = [(float)2, 3, 1];
-  Fn->sort_float($nums, 0, scalar @$nums, method : int ($a : float, $b : float) {
-    return $a <=> $b;
-  });
-
-  # Sort double array itself by asc order
-  my $nums = [(double)2, 3, 1];
-  Fn->sort_double($nums, 0, scalar @$nums, method : int ($a : double, $b : double) {
-    return $a <=> $b;
-  });
-
-  # Sort string array itself by asc order
-  my $nums = ["11", "1", "2", undef, ""];
-  Fn->sort_double($nums, 0, scalar @$nums, method : int ($a : double, $b : double) {
-    return $a <=> $b;
-  });
-
-  # Sort object array itself by asc order
-  my $minimals = new TestCase::Minimal[3];
-  $minimals->[0] = TestCase::Minimal->new;
-  $minimals->[0]{x} = 3;
-  $minimals->[0]{y} = 5;
-  $minimals->[1] = TestCase::Minimal->new;
-  $minimals->[1]{x} = 3;
-  $minimals->[1]{y} = 7;
-  $minimals->[2] = TestCase::Minimal->new;
-  $minimals->[2]{x} = 2;
-  $minimals->[2]{y} = 9;
-  Fn->sort_object($minimals, 0, scalar @$minimals, method : int ($object1 : object, $object2 : object) {
-    my $minimal1 = (TestCase::Minimal)$object1;
-    my $minimal2 = (TestCase::Minimal)$object2;
-    
-    return $minimal1->{x} <=> $minimal2->{x} || $minimal1->{y} <=> $minimal2->{y};
-  };
-
-=head1 DESCRIPTION
+=head1 Description
 
 B<Fn> module provides SPVM Starndard Functions. B<Fn> contains number, string and array utilities.
 
-=head1 CLASS METHODS
+=head1 Class Methods
 
 Class method of B<Fn> module.
 
@@ -1126,6 +1066,24 @@ Destnation offset + length must be within the range of the destnation array, oth
 
 Source offset + length must be within the range of the source array, otherwise an exception occurs.
 
+=head2 memcpy_object
+
+  static method memcpy_object : void ($dest : object[], $dest_offset : int, $source : object[], $source_offset : int, $length : int)
+
+Copy source object array to destination object array with the each offset and a length.
+
+If source data range and destination data overlap, the result is not guaranteed.
+
+Destnation must be defined, otherwise an exception occurs.
+
+Source must be defined, otherwise an exception occurs.
+
+Length must be more than or equals to 0, otherwise an exception occurs.
+
+Destnation offset + length must be within the range of the destnation array, otherwise an exception occurs.
+
+Source offset + length must be within the range of the source array, otherwise an exception occurs.
+
 =head2 memmove
 
   static method memmove : void ($dest : object, $dest_byte_offset : int, $source : object, $source_byte_offset : int, $byte_length : int);
@@ -1258,12 +1216,72 @@ Destnation offset + length must be within the range of the destnation array, oth
 
 Source offset + length must be within the range of the source array, otherwise an exception occurs.
 
+=head2 memmove_object
+
+  static method memmove_object : void ($dest : object[], $dest_offset : int, $source : object[], $source_offset : int, $length : int)
+
+Copy source object array to destination object array with the each offset and a length.
+
+If source data range and destination data overlap, the result is guaranteed.
+
+Destnation must be defined, otherwise an exception occurs.
+
+Source must be defined, otherwise an exception occurs.
+
+Length must be more than or equals to 0, otherwise an exception occurs.
+
+Destnation offset + length must be within the range of the destnation array, otherwise an exception occurs.
+
+Source offset + length must be within the range of the source array, otherwise an exception occurs.
+
 =head2 new_array_proto
 
   static method new_array_proto : object[] ($proto_array : object[], $length : int)
 
 Create a new generic object array as the same type as the given array.
 
+=head2 memset_byte
+
+  static method memset_byte : void ($dest : byte[], $dest_offset : int, $value : byte, $length : int)
+
+Set each element of the C<byte> array to the value with the offset and the length.
+
+=head2 memset_double
+
+  static method memset_double : void ($dest : double[], $dest_offset : int, $value : double, $length : int)
+
+Set each element of the C<double> array to the value with the offset and the length.
+
+=head2 memset_float
+
+  static method memset_float : void ($dest : float[], $dest_offset : int, $value : float, $length : int)
+
+Set each element of the C<float> array to the value with the offset and the length.
+
+=head2 memset_int
+
+  static method memset_int : void ($dest : int[], $dest_offset : int, $value : int, $length : int)
+
+Set each element of the C<int> array to the value with the offset and the length.
+
+=head2 memset_long
+
+  static method memset_long : void ($dest : long[], $dest_offset : int, $value : long, $length : int)
+
+Set each element of the C<long> array to the value with the offset and the length.
+
+=head2 memset_short
+
+  static method memset_short : void ($dest : short[], $dest_offset : int, $value : short, $length : int)
+
+Set each element of the C<short> array to the value with the offset and the length.
+
+=head2 memset_object
+
+  static method memset_object : void ($dest : object[], $dest_offset : int : int, $value : object, $length)
+
+Set each element of the object array to the value with the offset and the length.
+
 =head2 ord
 
   static method ord : int ($utf8_character : string)
@@ -1349,118 +1367,6 @@ If the given length is lower than C<0>, the given length become C<0>.
 
 In the level of native APIs, the charaters of the after the given length are filled with C<\0>.
 
-=head2 sort_byte
-
-    static method sort_byte : void ($nums : byte[], $offset : int, $length : int, $comparator : Comparator::Byte)
-
-Sort byte array itself with a offset, a length, and a L<Comparator::Byte|SPVM::Comparator::Byte> comparator.
-
-Array must be not undef. Otherwise an exception occurs.
-
-Offset must be more than or equals to 0. Otherwise an exception occurs.
-
-Length must be more than or equals to 0. Otherwise an exception occurs.
-
-Offset + Length must be in the array range. Otherwise an exception occurs.
-
-=head2 sort_double
-
-    static method sort_double : void ($nums : double[], $offset : int, $length : int, $comparator : Comparator::Double)
-
-Sort double array itself with a offset, a length, and a L<Comparator::Double|SPVM::Comparator::Double> comparator.
-
-Array must be not undef. Otherwise an exception occurs.
-
-Offset must be more than or equals to 0. Otherwise an exception occurs.
-
-Length must be more than or equals to 0. Otherwise an exception occurs.
-
-Offset + Length must be in the array range. Otherwise an exception occurs.
-
-=head2 sort_float
-
-    static method static method sort_float : void ($nums : float[], $offset : int, $length : int, $comparator : Comparator::Float)
-
-Sort float array itself with a offset, a length, and a L<Comparator::Float|SPVM::Comparator::Float> comparator.
-
-Array must be not undef. Otherwise an exception occurs.
-
-Offset must be more than or equals to 0. Otherwise an exception occurs.
-
-Length must be more than or equals to 0. Otherwise an exception occurs.
-
-Offset + Length must be in the array range. Otherwise an exception occurs.
-
-=head2 sort_int
-
-    static method sort_int : void ($nums : int[], $offset : int, $length : int, $comparator : Comparator::Int)
-
-Sort int array itself with a offset, a length, and a L<Comparator::Int|SPVM::Comparator::Int> comparator.
-
-Array must be not undef. Otherwise an exception occurs.
-
-Offset must be more than or equals to 0. Otherwise an exception occurs.
-
-Length must be more than or equals to 0. Otherwise an exception occurs.
-
-Offset + Length must be in the array range. Otherwise an exception occurs.
-
-=head2 sort_long
-
-    static method sort_long : void ($nums : long[], $offset : int, $length : int, $comparator : Comparator::Long)
-
-Sort long array itself with a offset, a length, and a L<Comparator::Long|SPVM::Comparator::Long> comparator.
-
-Array must be not undef. Otherwise an exception occurs.
-
-Offset must be more than or equals to 0. Otherwise an exception occurs.
-
-Length must be more than or equals to 0. Otherwise an exception occurs.
-
-Offset + Length must be in the array range. Otherwise an exception occurs.
-
-=head2 sort_object
-
-    static method sort_object : void ($objs : object[], $offset : int, $length : int, $comparator : Comparator)
-
-Sort object array itself with a offset, a length, and a L<Comparator|SPVM::Comparator> comparator.
-
-Array must be not undef. Otherwise an exception occurs.
-
-Offset must be more than or equals to 0. Otherwise an exception occurs.
-
-Length must be more than or equals to 0. Otherwise an exception occurs.
-
-Offset + Length must be in the array range. Otherwise an exception occurs.
-
-=head2 sort_short
-
-    static method sort_short : void ($nums : short[], $offset : int, $length : int, $comparator : Comparator::Short)
-
-Sort short array itself with a offset, a length, and a L<Comparator::Short|SPVM::Comparator::Short> comparator.
-
-Array must be not undef. Otherwise an exception occurs.
-
-Offset must be more than or equals to 0. Otherwise an exception occurs.
-
-Length must be more than or equals to 0. Otherwise an exception occurs.
-
-Offset + Length must be in the array range. Otherwise an exception occurs.
-
-=head2 sort_string
-
-    static method sort_string : void ($nums : string[], $offset : int, $length : int, $comparator : Comparator::Double)
-
-Sort string array itself with a offset, a length, and a L<Comparator::String|SPVM::Comparator::String> comparator.
-
-Array must be not undef. Otherwise an exception occurs.
-
-Offset must be more than or equals to 0. Otherwise an exception occurs.
-
-Length must be more than or equals to 0. Otherwise an exception occurs.
-
-Offset + Length must be in the array range. Otherwise an exception occurs.
-
 =head2 split
 
   static method split : string[] ($sep : string, $string : string)
